@@ -17,18 +17,18 @@ class SerialCommunicator(Communicator):
 
     def run(self):
         logger.info('SerialCommunicator started')
-        while not self._stop.is_set():
+        while not self._stop_flag.is_set():
             # If there's messages in transmit queue
             # send them
             while True:
                 p = self._get_from_send_queue()
                 if not p:
                     break
-                self.__ser.write(str(bytearray(p.build())))
+                self.__ser.write(bytearray(p.build()))
 
             # Read chars from serial port as hex numbers
             try:
-                self._buffer.extend([ord(c) for c in self.__ser.read(16)])
+                self._buffer.extend(bytearray(self.__ser.read(16)))
             except serial.SerialException:
                 logger.error('Serial port exception! (device disconnected or multiple access on port?)')
                 break
